@@ -1,8 +1,11 @@
 import warnings
 import importlib
 from typing import Any
+
 from dotenv import load_dotenv
 
+from upsonic.utils.logging_config import *
+
 warnings.filterwarnings("ignore", category=ResourceWarning)
 warnings.filterwarnings("ignore", category=PendingDeprecationWarning)
 warnings.filterwarnings("ignore", category=DeprecationWarning)
@@ -34,6 +37,12 @@ def _get_KnowledgeBase():
 def _get_Agent():
     return _lazy_import("upsonic.agent.agent", "Agent")()
 
+def _get_DeepAgent():
+    return _lazy_import("upsonic.agent.deep_agent", "DeepAgent")()
+
+def _get_create_deep_agent():
+    return _lazy_import("upsonic.agent.deep_agent", "create_deep_agent")()
+
 def _get_AgentRunResult():
     return _lazy_import("upsonic.agent.run_result", "AgentRunResult")()
 
@@ -70,6 +79,56 @@ def _get_tool():
 def _get_Chat():
     return _lazy_import("upsonic.chat.chat", "Chat")()
 
+def _get_Direct():
+    return _lazy_import("upsonic.direct", "Direct")()
+
+def _get_OCR():
+    return _lazy_import("upsonic.ocr.ocr", "OCR")()
+
+def _get_Memory():
+    return _lazy_import("upsonic.storage.memory.memory", "Memory")()
+
+def _get_durable_execution_components():
+    """Lazy import of durable execution components."""
+    from upsonic.durable import (
+        DurableExecution,
+        DurableExecutionStorage,
+        InMemoryDurableStorage,
+        FileDurableStorage,
+        SQLiteDurableStorage,
+        RedisDurableStorage
+    )
+    
+    return {
+        "DurableExecution": DurableExecution,
+        "DurableExecutionStorage": DurableExecutionStorage,
+        "InMemoryDurableStorage": InMemoryDurableStorage,
+        "FileDurableStorage": FileDurableStorage,
+        "SQLiteDurableStorage": SQLiteDurableStorage,
+        "RedisDurableStorage": RedisDurableStorage,
+    }
+
+def _get_database_components():
+    """Lazy import of database components."""
+    try:
+        from upsonic.db import (
+            DatabaseBase, SqliteDatabase, PostgresDatabase, MongoDatabase,
+            RedisDatabase, InMemoryDatabase, JSONDatabase, Mem0Database
+        )
+        
+        return {
+            "DatabaseBase": DatabaseBase,
+            "SqliteDatabase": SqliteDatabase,
+            "PostgresDatabase": PostgresDatabase,
+            "MongoDatabase": MongoDatabase,
+            "RedisDatabase": RedisDatabase,
+            "InMemoryDatabase": InMemoryDatabase,
+            "JSONDatabase": JSONDatabase,
+            "Mem0Database": Mem0Database,
+        }
+    except ImportError:
+        return {}
+
 def _get_safety_engine_components():
     """Lazy import of safety engine components to avoid circular imports."""
     try:
@@ -146,6 +205,10 @@ def __getattr__(name: str) -> Any:
         return _get_KnowledgeBase()
     elif name == "Agent":
         return _get_Agent()
+    elif name == "DeepAgent":
+        return _get_DeepAgent()
+    elif name == "create_deep_agent":
+        return _get_create_deep_agent()
     elif name == "AgentRunResult":
         return _get_AgentRunResult()
     elif name == "OutputDataT":
@@ -170,6 +233,20 @@ def __getattr__(name: str) -> Any:
         return _get_tool()
     elif name == "Chat":
         return _get_Chat()
+    elif name == "Direct":
+        return _get_Direct()
+    elif name == "OCR":
+        return _get_OCR()
+    elif name == "Memory":
+        return _get_Memory()
+    
+    database_components = _get_database_components()
+    if name in database_components:
+        return database_components[name]
+    
+    durable_components = _get_durable_execution_components()
+    if name in durable_components:
+        return durable_components[name]
     
     safety_components = _get_safety_engine_components()
     if name in safety_components:
@@ -201,6 +278,9 @@ __all__ = [
     "MultiAgent",
     "Team",
     "Chat",
+    "Direct",
+    "OCR",
+    "Memory",
     "UupsonicError",
     "AgentExecutionError", 
     "ModelConnectionError", 
@@ -232,4 +312,18 @@ __all__ = [
     "SensitiveSocialRaiseExceptionPolicy_LLM",
     "AnonymizePhoneNumbersPolicy_LLM_Finder",
     "tool",
+    "DatabaseBase",
+    "SqliteDatabase",
+    "PostgresDatabase",
+    "MongoDatabase",
+    "RedisDatabase",
+    "InMemoryDatabase",
+    "JSONDatabase",
+    "Mem0Database",
+    "DurableExecution",
+    "DurableExecutionStorage",
+    "InMemoryDurableStorage",
+    "FileDurableStorage",
+    "SQLiteDurableStorage",
+    "RedisDurableStorage",
 ]
\ No newline at end of file
