@@ -6,20 +6,22 @@ from .config import LoaderConfig, LoaderConfigFactory
 
 if TYPE_CHECKING:
     from .config import (
-        TextLoaderConfig, CSVLoaderConfig, PdfLoaderConfig, PyMuPDFLoaderConfig,
+        TextLoaderConfig, CSVLoaderConfig, PdfLoaderConfig, PyMuPDFLoaderConfig, PdfPlumberLoaderConfig,
         DOCXLoaderConfig, JSONLoaderConfig, XMLLoaderConfig, YAMLLoaderConfig,
-        MarkdownLoaderConfig, HTMLLoaderConfig, simple_config, advanced_config
+        MarkdownLoaderConfig, HTMLLoaderConfig, DoclingLoaderConfig, simple_config, advanced_config
     )
     from .text import TextLoader
     from .csv import CSVLoader
     from .pdf import PdfLoader
     from .pymupdf import PyMuPDFLoader
+    from .pdfplumber import PdfPlumberLoader
     from .docx import DOCXLoader
     from .json import JSONLoader
     from .xml import XMLLoader
     from .yaml import YAMLLoader
     from .markdown import MarkdownLoader
     from .html import HTMLLoader
+    from .docling import DoclingLoader
     from .factory import (
         LoaderFactory, get_factory, create_loader, create_loader_for_file,
         create_loader_for_content, can_handle_file, get_supported_extensions,
@@ -35,6 +37,7 @@ def _get_loader_classes():
     from .csv import CSVLoader
     from .pdf import PdfLoader
     from .pymupdf import PyMuPDFLoader
+    from .pdfplumber import PdfPlumberLoader
     from .docx import DOCXLoader
     from .json import JSONLoader
     from .xml import XMLLoader
@@ -42,11 +45,12 @@ def _get_loader_classes():
     from .markdown import MarkdownLoader
     from .html import HTMLLoader
     
-    return {
+    loaders = {
         'TextLoader': TextLoader,
         'CSVLoader': CSVLoader,
         'PdfLoader': PdfLoader,
         'PyMuPDFLoader': PyMuPDFLoader,
+        'PdfPlumberLoader': PdfPlumberLoader,
         'DOCXLoader': DOCXLoader,
         'JSONLoader': JSONLoader,
         'XMLLoader': XMLLoader,
@@ -54,13 +58,22 @@ def _get_loader_classes():
         'MarkdownLoader': MarkdownLoader,
         'HTMLLoader': HTMLLoader,
     }
+    
+    # Try to import DoclingLoader (optional dependency)
+    try:
+        from .docling import DoclingLoader
+        loaders['DoclingLoader'] = DoclingLoader
+    except ImportError:
+        pass  # Docling not installed
+    
+    return loaders
 
 def _get_config_classes():
     """Lazy import of config classes."""
     from .config import (
-        TextLoaderConfig, CSVLoaderConfig, PdfLoaderConfig, PyMuPDFLoaderConfig,
+        TextLoaderConfig, CSVLoaderConfig, PdfLoaderConfig, PyMuPDFLoaderConfig, PdfPlumberLoaderConfig,
         DOCXLoaderConfig, JSONLoaderConfig, XMLLoaderConfig, YAMLLoaderConfig,
-        MarkdownLoaderConfig, HTMLLoaderConfig, simple_config, advanced_config
+        MarkdownLoaderConfig, HTMLLoaderConfig, DoclingLoaderConfig, simple_config, advanced_config
     )
     
     return {
@@ -68,12 +81,14 @@ def _get_config_classes():
         'CSVLoaderConfig': CSVLoaderConfig,
         'PdfLoaderConfig': PdfLoaderConfig,
         'PyMuPDFLoaderConfig': PyMuPDFLoaderConfig,
+        'PdfPlumberLoaderConfig': PdfPlumberLoaderConfig,
         'DOCXLoaderConfig': DOCXLoaderConfig,
         'JSONLoaderConfig': JSONLoaderConfig,
         'XMLLoaderConfig': XMLLoaderConfig,
         'YAMLLoaderConfig': YAMLLoaderConfig,
         'MarkdownLoaderConfig': MarkdownLoaderConfig,
         'HTMLLoaderConfig': HTMLLoaderConfig,
+        'DoclingLoaderConfig': DoclingLoaderConfig,
         'simple_config': simple_config,
         'advanced_config': advanced_config,
     }
@@ -129,12 +144,12 @@ def __getattr__(name: str) -> Any:
 __all__ = [
     'BaseLoader',
 
-    'LoaderConfig', 'TextLoaderConfig', 'CSVLoaderConfig', 'PdfLoaderConfig', 'PyMuPDFLoaderConfig',
+    'LoaderConfig', 'TextLoaderConfig', 'CSVLoaderConfig', 'PdfLoaderConfig', 'PyMuPDFLoaderConfig', 'PdfPlumberLoaderConfig',
     'DOCXLoaderConfig', 'JSONLoaderConfig', 'XMLLoaderConfig', 'YAMLLoaderConfig',
-    'MarkdownLoaderConfig', 'HTMLLoaderConfig', 'LoaderConfigFactory', 'simple_config', 'advanced_config',
+    'MarkdownLoaderConfig', 'HTMLLoaderConfig', 'DoclingLoaderConfig', 'LoaderConfigFactory', 'simple_config', 'advanced_config',
     
-    'TextLoader', 'CSVLoader', 'PdfLoader', 'PyMuPDFLoader', 'DOCXLoader',
-    'JSONLoader', 'XMLLoader', 'YAMLLoader', 'MarkdownLoader', 'HTMLLoader',
+    'TextLoader', 'CSVLoader', 'PdfLoader', 'PyMuPDFLoader', 'PdfPlumberLoader', 'DOCXLoader',
+    'JSONLoader', 'XMLLoader', 'YAMLLoader', 'MarkdownLoader', 'HTMLLoader', 'DoclingLoader',
     
     'LoaderFactory', 'get_factory', 'create_loader', 'create_loader_for_file',
     'create_loader_for_content', 'can_handle_file', 'get_supported_extensions',
