@@ -3,17 +3,17 @@ from typing import Dict, Type, Optional, List, Union, Any, Tuple, TYPE_CHECKING
 import os
 import json
 from pathlib import Path
-import logging
 from functools import lru_cache
 
+from upsonic.utils.logging_config import get_logger
 from .base import BaseLoader
 from .config import LoaderConfig, LoaderConfigFactory
 
 if TYPE_CHECKING:
     from upsonic.schemas.data_models import Document
     from .config import (
-        TextLoaderConfig, CSVLoaderConfig, PdfLoaderConfig, DOCXLoaderConfig, 
-        JSONLoaderConfig, XMLLoaderConfig, YAMLLoaderConfig, MarkdownLoaderConfig, 
+        TextLoaderConfig, CSVLoaderConfig, PdfLoaderConfig, DOCXLoaderConfig,
+        JSONLoaderConfig, XMLLoaderConfig, YAMLLoaderConfig, MarkdownLoaderConfig,
         HTMLLoaderConfig
     )
     from .text import TextLoader
@@ -26,26 +26,26 @@ if TYPE_CHECKING:
     from .markdown import MarkdownLoader
     from .html import HTMLLoader
 
+logger = get_logger(__name__)
 
 class LoaderFactory:
     """
     A factory class for creating and managing document loaders.
-    
+
     This factory provides intelligent loader creation, configuration management,
     and extension-based loader detection. It supports both synchronous and
     asynchronous operations with proper error handling and fallback mechanisms.
     """
-    
+
     _REQUIRED_METHODS = ['load', 'aload', 'batch', 'abatch', 'get_supported_extensions']
     _URL_PREFIXES = ('http://', 'https://', 'ftp://')
     _CONTENT_PREVIEW_SIZE = 1024
     _LARGE_FILE_THRESHOLD = 100 * 1024 * 1024
-    _PDF_LARGE_THRESHOLD = 50 * 1024 * 1024    
+    _PDF_LARGE_THRESHOLD = 50 * 1024 * 1024
     def __init__(self):
         self._loaders: Dict[str, Type[BaseLoader]] = {}
         self._extensions: Dict[str, str] = {}
         self._configs: Dict[str, Type[LoaderConfig]] = {}
-        self._logger = logging.getLogger(__name__)
         
         self._register_default_loaders()
         self._validate_registration()
@@ -63,6 +63,7 @@ class LoaderFactory:
         from .csv import CSVLoader
         from .pdf import PdfLoader
         from .pymupdf import PyMuPDFLoader
+        from .pdfplumber import PdfPlumberLoader
         from .docx import DOCXLoader
         from .json import JSONLoader
         from .xml import XMLLoader
@@ -71,10 +72,11 @@ class LoaderFactory:
         from .html import HTMLLoader
         from .text import TextLoader
         
-        return [
+        loaders = [
             (CSVLoader, ['.csv']),
             (PdfLoader, ['.pdf']),
-            (PyMuPDFLoader, ['.pdf']),  # Alternative PDF loader
+            (PyMuPDFLoader, ['.pdf']),  # Alternative PDF loader with PyMuPDF
+            (PdfPlumberLoader, ['.pdf']),  # Alternative PDF loader with pdfplumber (superior tables)
             (DOCXLoader, ['.docx']),
             (JSONLoader, ['.json', '.jsonl']),
             (XMLLoader, ['.xml']),
@@ -83,6 +85,23 @@ class LoaderFactory:
             (HTMLLoader, ['.html', '.htm', '.xhtml']),
             (TextLoader, ['.txt', '.rst', '.log', '.py', '.js', '.ts', '.java', '.c', '.cpp', '.h', '.cs', '.go', '.rs', '.php', '.rb', '.css', '.ini'])
         ]
+        
+        # Try to import DoclingLoader (optional dependency)
+        try:
+            from .docling import DoclingLoader
+            # Docling supports a wide range of formats, register with high priority
+            loaders.insert(0, (DoclingLoader, [
+                '.pdf', '.docx', '.xlsx', '.pptx',
+                '.html', '.htm',
+                '.md', '.markdown',
+                '.adoc', '.asciidoc',
+                '.csv',
+                '.png', '.jpg', '.jpeg', '.tiff', '.bmp', '.webp'
+            ]))
+        except ImportError:
+            pass  # Docling not installed, skip registration
+        
+        return loaders
     
     def register_loader(self, loader_class: Type[BaseLoader], extensions: List[str]):
         """
@@ -114,10 +133,10 @@ class LoaderFactory:
                 conflicting_extensions.append(ext)
         
         if conflicting_extensions:
-            self._logger.warning(f"Extension conflicts detected for {loader_name}: {conflicting_extensions}")
+            logger.warning(f"Extension conflicts detected for {loader_name}: {conflicting_extensions}")
             for ext in conflicting_extensions:
                 old_loader = self._extensions[ext.lower()]
-                self._logger.info(f"Replacing {old_loader} with {loader_name} for extension {ext}")
+                logger.info(f"Replacing {old_loader} with {loader_name} for extension {ext}")
         
         self._loaders[loader_name] = loader_class
         
@@ -129,22 +148,23 @@ class LoaderFactory:
         if loader_name in config_mapping:
             self._configs[loader_name] = config_mapping[loader_name]
         
-        self._logger.debug(f"Registered loader '{loader_name}' with extensions: {extensions}")
+        logger.debug(f"Registered loader '{loader_name}' with extensions: {extensions}")
     
     @staticmethod
     def _get_config_mapping() -> Dict[str, Type[LoaderConfig]]:
         """Get the mapping of loader names to their config classes with lazy imports."""
         from .config import (
-            TextLoaderConfig, CSVLoaderConfig, PdfLoaderConfig, PyMuPDFLoaderConfig, DOCXLoaderConfig,
-            JSONLoaderConfig, XMLLoaderConfig, YAMLLoaderConfig, MarkdownLoaderConfig,
+            TextLoaderConfig, CSVLoaderConfig, PdfLoaderConfig, PyMuPDFLoaderConfig, PdfPlumberLoaderConfig,
+            DOCXLoaderConfig, JSONLoaderConfig, XMLLoaderConfig, YAMLLoaderConfig, MarkdownLoaderConfig,
             HTMLLoaderConfig
         )
         
-        return {
+        config_map = {
             'text': TextLoaderConfig,
             'csv': CSVLoaderConfig,
             'pdf': PdfLoaderConfig,
             'pymupdf': PyMuPDFLoaderConfig,
+            'pdfplumber': PdfPlumberLoaderConfig,
             'docx': DOCXLoaderConfig,
             'json': JSONLoaderConfig,
             'xml': XMLLoaderConfig,
@@ -152,6 +172,15 @@ class LoaderFactory:
             'markdown': MarkdownLoaderConfig,
             'html': HTMLLoaderConfig
         }
+        
+        # Try to add DoclingLoaderConfig if available
+        try:
+            from .config import DoclingLoaderConfig
+            config_map['docling'] = DoclingLoaderConfig
+        except ImportError:
+            pass  # Docling not installed
+        
+        return config_map
     
     def _validate_registration(self):
         """Validate that all registered loaders are properly configured."""
@@ -164,13 +193,13 @@ class LoaderFactory:
         for loader_name, loader_class in self._loaders.items():
             for method in self._REQUIRED_METHODS:
                 if not hasattr(loader_class, method):
-                    self._logger.warning(f"Loader {loader_name} missing required method: {method}")
+                    logger.warning(f"Loader {loader_name} missing required method: {method}")
     
     def _validate_loader_configs(self):
         """Validate that all loaders have config classes."""
         for loader_name in self._loaders:
             if loader_name not in self._configs:
-                self._logger.warning(f"No config class found for loader: {loader_name}")
+                logger.warning(f"No config class found for loader: {loader_name}")
     
     def _check_duplicate_extensions(self):
         """Check for duplicate extensions across loaders."""
@@ -180,7 +209,7 @@ class LoaderFactory:
         
         duplicates = {ext: count for ext, count in extension_counts.items() if count > 1}
         if duplicates:
-            self._logger.warning(f"Duplicate extensions found: {duplicates}")
+            logger.warning(f"Duplicate extensions found: {duplicates}")
     
     def get_loader(self, source: str, loader_type: Optional[str] = None, **config_kwargs) -> BaseLoader:
         """
@@ -223,7 +252,7 @@ class LoaderFactory:
             return loader_class(config)
             
         except Exception as e:
-            self._logger.error(f"Failed to create loader for '{source}': {e}")
+            logger.error(f"Failed to create loader for '{source}': {e}")
             raise
     
     def create_intelligent_loaders(self, sources: List[Union[str, Path]], **global_config_kwargs) -> List[BaseLoader]:
@@ -245,7 +274,7 @@ class LoaderFactory:
         
         for source in sources:
             if isinstance(source, str):
-                self._logger.debug(f"Skipping loader creation for string content: {source[:50]}...")
+                logger.debug(f"Skipping loader creation for string content: {source[:50]}...")
                 continue
                 
             try:
@@ -258,17 +287,17 @@ class LoaderFactory:
                 loader = self.get_loader(source_str, loader_type, **source_config)
                 loaders.append(loader)
                 
-                self._logger.debug(f"Created {loader_type} loader for {source}")
+                logger.debug(f"Created {loader_type} loader for {source}")
                 
             except Exception as e:
-                self._logger.warning(f"Failed to create loader for {source}: {e}")
+                logger.warning(f"Failed to create loader for {source}: {e}")
                 try:
                     fallback_config = self._create_optimized_config(source_str, 'text', **global_config_kwargs)
                     fallback_loader = self.get_loader(source_str, 'text', **fallback_config)
                     loaders.append(fallback_loader)
-                    self._logger.info(f"Using text loader fallback for {source}")
+                    logger.info(f"Using text loader fallback for {source}")
                 except Exception as fallback_error:
-                    self._logger.error(f"Fallback loader also failed for {source}: {fallback_error}")
+                    logger.error(f"Fallback loader also failed for {source}: {fallback_error}")
                     raise
         
         return loaders
@@ -305,6 +334,8 @@ class LoaderFactory:
             self._optimize_pdf_config(config, file_size)
         elif loader_type == 'pymupdf':
             self._optimize_pymupdf_config(config, file_size)
+        elif loader_type == 'docling':
+            self._optimize_docling_config(config, file_size, source)
         elif loader_type == 'html':
             self._optimize_html_config(config, source)
         elif loader_type == 'csv':
@@ -343,6 +374,48 @@ class LoaderFactory:
             config.setdefault('image_dpi', 150)  # Higher DPI for better quality
             config.setdefault('text_extraction_method', 'dict')  # Better structure for smaller files
     
+    def _optimize_docling_config(self, config: Dict[str, Any], file_size: int, source: str) -> None:
+        """Optimize Docling loader configuration based on file size and source type."""
+        # Determine if source is URL
+        is_url = source.startswith(('http://', 'https://'))
+        
+        if is_url:
+            config.setdefault('support_urls', True)
+            config.setdefault('url_timeout', 60)  # Longer timeout for URLs
+        
+        # Optimize based on file size
+        if file_size > self._PDF_LARGE_THRESHOLD:
+            # Large files: prioritize speed
+            config.setdefault('extraction_mode', 'chunks')
+            config.setdefault('chunker_type', 'hybrid')
+            config.setdefault('max_pages', 100)  # Limit pages for very large files
+            config.setdefault('parallel_processing', True)
+            config.setdefault('batch_size', 5)
+            config.setdefault('extract_document_metadata', False)
+            
+            # OCR: Disable for speed on large files
+            config.setdefault('ocr_enabled', False)
+            config.setdefault('enable_table_structure', True)
+            config.setdefault('table_structure_cell_matching', False)  # Disable cell matching for speed
+        else:
+            # Smaller files: prioritize quality
+            config.setdefault('extraction_mode', 'chunks')
+            config.setdefault('chunker_type', 'hierarchical')  # Better structure for smaller files
+            config.setdefault('parallel_processing', True)
+            config.setdefault('batch_size', 10)
+            config.setdefault('extract_document_metadata', True)
+            config.setdefault('confidence_threshold', 0.7)  # Higher quality threshold
+            
+            # OCR: Full features for quality
+            config.setdefault('ocr_enabled', True)
+            config.setdefault('ocr_force_full_page', False)  # Hybrid mode (smart OCR)
+            config.setdefault('ocr_backend', 'rapidocr')  # Fast and accurate
+            config.setdefault('ocr_lang', ['english'])
+            config.setdefault('ocr_backend_engine', 'onnxruntime')  # Best compatibility
+            config.setdefault('ocr_text_score', 0.6)  # Good balance
+            config.setdefault('enable_table_structure', True)
+            config.setdefault('table_structure_cell_matching', True)  # Full quality
+    
     def _optimize_html_config(self, config: Dict[str, Any], source: str) -> None:
         """Optimize HTML loader configuration for URLs."""
         if source.startswith(self._URL_PREFIXES):
@@ -541,7 +614,7 @@ class LoaderFactory:
             else:
                 return self._create_fallback_config(loader_name, config_kwargs)
         except Exception as e:
-            self._logger.warning(f"Failed to create config for '{loader_name}': {e}")
+            logger.warning(f"Failed to create config for '{loader_name}': {e}")
             return self._create_base_config(config_kwargs)
     
     def _create_specific_config(self, loader_name: str, config_kwargs: Dict[str, Any]) -> LoaderConfig:
@@ -574,7 +647,7 @@ class LoaderFactory:
                 invalid_params.append(param_name)
         
         if invalid_params:
-            self._logger.warning(f"Invalid config parameters for {config_class.__name__}: {invalid_params}")
+            logger.warning(f"Invalid config parameters for {config_class.__name__}: {invalid_params}")
             for param in invalid_params:
                 config_kwargs.pop(param, None)
     
@@ -626,7 +699,7 @@ class LoaderFactory:
                 loader = self.get_loader_for_file(str(file_path), **config_kwargs)
                 loaders[str(file_path)] = loader
             except Exception as e:
-                self._logger.warning(f"Could not create loader for {file_path}: {e}")
+                logger.warning(f"Could not create loader for {file_path}: {e}")
                 continue
         
         return loaders
@@ -694,7 +767,7 @@ class LoaderFactory:
     def clear_cache(self):
         """Clear any cached data."""
         self._detect_loader_type.cache_clear()
-        self._logger.debug("Factory cache cleared")
+        logger.debug("Factory cache cleared")
     
     def get_loader_statistics(self) -> Dict[str, Any]:
         """Get statistics about registered loaders."""
