@@ -10,25 +10,21 @@ from upsonic.loaders.config import PdfLoaderConfig
 
 try:
     from pypdf import PdfReader, PageObject
-except ImportError as _import_error:
-    from upsonic.utils.printing import import_error
-    import_error(
-        package_name="pypdf",
-        install_command='pip install "upsonic[loaders]"',
-        feature_name="PDF loader"
-    )
+    _PYPDF_AVAILABLE = True
+except ImportError:
+    PdfReader = None
+    PageObject = None
+    _PYPDF_AVAILABLE = False
 
 
 try:
     from rapidocr_onnxruntime import RapidOCR
     OCR_ENGINE = RapidOCR()
-except ImportError as _import_error:
-    from upsonic.utils.printing import import_error
-    import_error(
-        package_name="rapidocr-onnxruntime",
-        install_command='pip install "upsonic[loaders]"',
-        feature_name="PDF OCR functionality"
-    )
+    _RAPIDOCR_AVAILABLE = True
+except ImportError:
+    RapidOCR = None
+    OCR_ENGINE = None
+    _RAPIDOCR_AVAILABLE = False
 
 
 
@@ -50,10 +46,22 @@ class PdfLoader(BaseLoader):
         Args:
             config: A PdfLoaderConfig object with settings for PDF processing.
         """
+        if not _PYPDF_AVAILABLE:
+            from upsonic.utils.printing import import_error
+            import_error(
+                package_name="pypdf",
+                install_command='pip install "upsonic[loaders]"',
+                feature_name="PDF loader"
+            )
+        if config.extraction_mode in ("ocr_only", "hybrid") and not _RAPIDOCR_AVAILABLE:
+            from upsonic.utils.printing import import_error
+            import_error(
+                package_name="rapidocr-onnxruntime",
+                install_command='pip install "upsonic[loaders]"',
+                feature_name="PDF OCR functionality"
+            )
         super().__init__(config)
         self.config: PdfLoaderConfig = config
-        
-        # OCR_ENGINE is now guaranteed to be available due to the try-except block above
 
 
     @classmethod
