@@ -2,8 +2,8 @@ import base64
 import time
 from pydantic import BaseModel
 from typing import Any, List, Dict, Optional, Type, Union, Callable, Literal, TYPE_CHECKING
+from upsonic.exceptions import FileNotFoundError
 
-# Heavy imports moved to lazy loading for faster startup
 if TYPE_CHECKING:
     from upsonic.utils.printing import get_price_id_total_cost
     from upsonic.messages.messages import BinaryContent
@@ -18,7 +18,7 @@ else:
     ExternalToolCall = "ExternalToolCall"
     auto_detect_best_embedding = "auto_detect_best_embedding"
 
-# Type aliases for better type safety
+
 CacheMethod = Literal["vector_search", "llm_call"]
 CacheEntry = Dict[str, Any]
 
@@ -54,8 +54,210 @@ class Task(BaseModel):
     _cache_hit: bool = False
     _original_input: Optional[str] = None
     _last_cache_entry: Optional[Dict[str, Any]] = None
+    
+    # Durable execution support
+    durable_execution: Optional[Any] = None  # DurableExecution instance
+    durable_checkpoint_enabled: bool = False
 
-
+    @staticmethod
+    def _is_file_path(item: Any) -> bool:
+        """
+        Check if an item is a valid file path.
+        
+        Args:
+            item: Any object to check
+            
+        Returns:
+            bool: True if the item is a string representing an existing file path
+            
+        Raises:
+            FileNotFoundError: If the file path exists but cannot be accessed, or if it looks like a file path but doesn't exist
+        """
+        if not isinstance(item, str):
+            return False
+        
+        import os
+        
+        # Check if it's a valid file path and the file exists
+        try:
+            if os.path.isfile(item):
+                # Additional check to ensure file is readable
+                if not os.access(item, os.R_OK):
+                    raise FileNotFoundError(item, "File exists but is not readable")
+                return True
+            elif os.path.isdir(item):
+                # It's a directory, not a file
+                return False
+            else:
+                # Check if it looks like a file path but doesn't exist
+                if (item.endswith(('.txt', '.pdf', '.docx', '.md', '.py', '.js', '.html', '.css', '.json', '.xml', '.csv')) or 
+                    ('/' in item or '\\' in item) and '.' in item):
+                    raise FileNotFoundError(item, "File does not exist")
+                return False
+        except (TypeError, ValueError, OSError) as e:
+            # If it's a string that looks like a file path but can't be accessed, raise error
+            if isinstance(item, str) and (item.endswith(('.txt', '.pdf', '.docx', '.md', '.py', '.js', '.html', '.css', '.json', '.xml', '.csv')) or '/' in item or '\\' in item):
+                raise FileNotFoundError(item, f"Cannot access file: {str(e)}")
+            return False
+    
+    @staticmethod
+    def _is_folder_path(item: Any) -> bool:
+        """
+        Check if an item is a valid folder/directory path.
+        
+        Args:
+            item: Any object to check
+            
+        Returns:
+            bool: True if the item is a string representing an existing directory
+            
+        Raises:
+            FileNotFoundError: If the folder path exists but cannot be accessed, or if it looks like a directory path but doesn't exist
+        """
+        if not isinstance(item, str):
+            return False
+        
+        import os
+        
+        # Check if it's a valid directory path and the directory exists
+        try:
+            if os.path.isdir(item):
+                # Additional check to ensure directory is readable
+                if not os.access(item, os.R_OK):
+                    raise FileNotFoundError(item, "Directory exists but is not readable")
+                return True
+            else:
+                # Check if it looks like a directory path but doesn't exist
+                # A path looks like a directory if it ends with / or \, or if it contains path separators
+                if (item.endswith('/') or item.endswith('\\') or 
+                    (('/' in item or '\\' in item) and not os.path.isfile(item))):
+                    raise FileNotFoundError(item, "Directory does not exist")
+                return False
+        except (TypeError, ValueError, OSError) as e:
+            # If it's a string that looks like a directory path but can't be accessed, raise error
+            if isinstance(item, str) and (item.endswith('/') or item.endswith('\\') or '/' in item or '\\' in item):
+                raise FileNotFoundError(item, f"Cannot access directory: {str(e)}")
+            return False
+    
+    @staticmethod
+    def _get_files_from_folder(folder_path: str) -> List[str]:
+        """
+        Recursively get all file paths from a folder.
+        
+        Args:
+            folder_path: Path to the folder
+            
+        Returns:
+            List[str]: List of all file paths in the folder and subfolders
+            
+        Raises:
+            FileNotFoundError: If the folder cannot be accessed
+        """
+        import os
+        
+        files = []
+        try:
+            for root, dirs, filenames in os.walk(folder_path):
+                for filename in filenames:
+                    file_path = os.path.join(root, filename)
+                    files.append(file_path)
+        except (OSError, PermissionError) as e:
+            # If we can't access the folder, raise a proper error
+            raise FileNotFoundError(folder_path, f"Cannot access folder: {str(e)}")
+        
+        return files
+    
+    @staticmethod
+    def _extract_files_from_context(context: Any) -> tuple[Any, List[str]]:
+        """
+        Extract file paths from context and return cleaned context and file list.
+        Also handles folders by extracting all files from them recursively.
+        
+        Args:
+            context: The context parameter (can be a list, dict, or any other type)
+            
+        Returns:
+            tuple: (cleaned_context, extracted_files)
+                - cleaned_context: Context with file/folder paths removed
+                - extracted_files: List of file paths found (including files from folders)
+                
+        Raises:
+            FileNotFoundError: If any file or folder in context cannot be accessed
+        """
+        extracted_files = []
+        
+        # If context is None or empty, return as is
+        if not context:
+            return context, extracted_files
+        
+        # Handle list context
+        if isinstance(context, list):
+            cleaned_context = []
+            for item in context:
+                try:
+                    if Task._is_file_path(item):
+                        extracted_files.append(item)
+                    elif Task._is_folder_path(item):
+                        # Extract all files from the folder
+                        folder_files = Task._get_files_from_folder(item)
+                        extracted_files.extend(folder_files)
+                    else:
+                        cleaned_context.append(item)
+                except FileNotFoundError:
+                    # Re-raise the exception with context
+                    raise
+            return cleaned_context, extracted_files
+        
+        # Handle dict context - check values
+        elif isinstance(context, dict):
+            cleaned_context = {}
+            for key, value in context.items():
+                try:
+                    if Task._is_file_path(value):
+                        extracted_files.append(value)
+                    elif Task._is_folder_path(value):
+                        # Extract all files from the folder
+                        folder_files = Task._get_files_from_folder(value)
+                        extracted_files.extend(folder_files)
+                    elif isinstance(value, list):
+                        # Recursively process lists in dict values
+                        cleaned_list = []
+                        for item in value:
+                            try:
+                                if Task._is_file_path(item):
+                                    extracted_files.append(item)
+                                elif Task._is_folder_path(item):
+                                    # Extract all files from the folder
+                                    folder_files = Task._get_files_from_folder(item)
+                                    extracted_files.extend(folder_files)
+                                else:
+                                    cleaned_list.append(item)
+                            except FileNotFoundError:
+                                # Re-raise the exception with context
+                                raise
+                        cleaned_context[key] = cleaned_list
+                    else:
+                        cleaned_context[key] = value
+                except FileNotFoundError:
+                    # Re-raise the exception with context
+                    raise
+            return cleaned_context, extracted_files
+        
+        # Handle single string that might be a file path or folder
+        try:
+            if Task._is_file_path(context):
+                extracted_files.append(context)
+                return [], extracted_files
+            elif Task._is_folder_path(context):
+                # Extract all files from the folder
+                folder_files = Task._get_files_from_folder(context)
+                extracted_files.extend(folder_files)
+                return [], extracted_files
+        except FileNotFoundError:
+            raise
+        
+        else:
+            return context, extracted_files
 
     def __init__(
         self, 
@@ -84,6 +286,7 @@ class Task(BaseModel):
         cache_threshold: float = 0.7,
         cache_embedding_provider: Optional[Any] = None,
         cache_duration_minutes: int = 60,
+        durable_execution: Optional[Any] = None,
     ):
         if guardrail is not None and not callable(guardrail):
             raise TypeError("The 'guardrail' parameter must be a callable function.")
@@ -109,6 +312,17 @@ class Task(BaseModel):
 
         if _tools_awaiting_external_execution is None:
             _tools_awaiting_external_execution = []
+        
+        try:
+            context, extracted_files = self._extract_files_from_context(context)
+        except FileNotFoundError as e:
+            raise FileNotFoundError(e.file_path, f"File specified in context cannot be accessed: {e.reason}")
+        
+        if attachments is None:
+            attachments = []
+        
+        if extracted_files:
+            attachments.extend(extracted_files)
             
         super().__init__(**{
             "description": description,
@@ -140,7 +354,9 @@ class Task(BaseModel):
             "_cache_manager": None,  # Will be set by Agent
             "_cache_hit": False,
             "_original_input": description,
-            "_last_cache_entry": None
+            "_last_cache_entry": None,
+            "durable_execution": durable_execution,
+            "durable_checkpoint_enabled": durable_execution is not None,
         })
         
         self.validate_tools()
@@ -188,6 +404,18 @@ class Task(BaseModel):
         """
         return self._tools_awaiting_external_execution
     
+    @property
+    def durable_execution_id(self) -> Optional[str]:
+        """
+        Get the durable execution ID for this task.
+        
+        Returns:
+            The execution ID if durable execution is enabled, None otherwise
+        """
+        if self.durable_execution:
+            return self.durable_execution.execution_id
+        return None
+    
     @context_formatted.setter
     def context_formatted(self, value: Optional[str]):
         """
@@ -271,7 +499,8 @@ class Task(BaseModel):
                     base64_attachments.append(base64_encoded)
             except Exception as e:
                 # Log the error but continue with other attachments
-                print(f"Warning: Could not encode attachment {attachment_path} to base64: {e}")
+                from upsonic.utils.printing import warning_log
+                warning_log(f"Could not encode attachment {attachment_path} to base64: {e}", "TaskProcessor")
         return base64_attachments
 
 
@@ -453,7 +682,8 @@ class Task(BaseModel):
                 input_list.append(BinaryContent(data=attachment_data, media_type=media_type))
                 
             except Exception as e:
-                print(f"Warning: Could not load image {attachment_path}: {e}")
+                from upsonic.utils.printing import warning_log
+                warning_log(f"Could not load image {attachment_path}: {e}", "TaskProcessor")
 
         return input_list
 
