@@ -1,4 +1,3 @@
-import logging
 import time
 from typing import Any, Dict, List, Optional, Union, Literal, Generator
 from concurrent.futures import ThreadPoolExecutor, as_completed
@@ -7,13 +6,14 @@ try:
     import pinecone
     from pinecone import Pinecone, ServerlessSpec
     from pinecone.exceptions import PineconeApiException as ApiException, NotFoundException
-except ImportError as _import_error:
-    from upsonic.utils.printing import import_error
-    import_error(
-        package_name="pinecone",
-        install_command='pip install "upsonic[rag]"',
-        feature_name="Pinecone vector database provider"
-    )
+    _PINECONE_AVAILABLE = True
+except ImportError:
+    pinecone = None
+    Pinecone = None
+    ServerlessSpec = None
+    ApiException = None
+    NotFoundException = None
+    _PINECONE_AVAILABLE = False
 
 
 from upsonic.vectordb.base import BaseVectorDBProvider
@@ -28,8 +28,8 @@ from upsonic.vectordb.config import (
 )
 
 from upsonic.utils.package.exception import(
-    VectorDBConnectionError, 
-    ConfigurationError, 
+    VectorDBConnectionError,
+    ConfigurationError,
     CollectionDoesNotExistError,
     VectorDBError,
     SearchError,
@@ -37,8 +37,9 @@ from upsonic.utils.package.exception import(
 )
 
 from upsonic.schemas.vector_schemas import VectorSearchResult
+from upsonic.utils.logging_config import get_logger
 
-logger = logging.getLogger(__name__)
+logger = get_logger(__name__)
 
 
 class PineconeProvider(BaseVectorDBProvider):
@@ -69,6 +70,13 @@ class PineconeProvider(BaseVectorDBProvider):
         provider instance is created in a valid, consistent, and ready-to-connect state,
         preventing runtime errors due to misconfiguration.
         """
+        if not _PINECONE_AVAILABLE:
+            from upsonic.utils.printing import import_error
+            import_error(
+                package_name="pinecone",
+                install_command='pip install "upsonic[rag]"',
+                feature_name="Pinecone vector database provider"
+            )
 
         super().__init__(config)
         
